@@ -12,7 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 #ifndef _POSTCHUNK_
 #define _POSTCHUNK_
@@ -33,6 +33,7 @@
 #include <map>
 #include <set>
 #include <vector>
+#include <queue>
 
 using namespace std;
 
@@ -50,14 +51,23 @@ private:
   map<string, set<string, Ltstr>, Ltstr> listslow;
   vector<xmlNode *> macro_map;
   vector<xmlNode *> rule_map;
+  vector<size_t> rule_lines;
   xmlDoc *doc;
   xmlNode *root_element;
   InterchunkWord **word;
-  string **blank;
-  int lword, lblank;
+  queue <string> blank_queue;
+  int lword;
   Buffer<TransferToken> input_buffer;
   vector<wstring *> tmpword;
   vector<wstring *> tmpblank;
+  
+  bool in_out;
+  bool in_lu;
+  bool in_let_var;
+  string var_val;
+  bool in_wblank;
+  string out_wblank;
+  map <string, string> var_out_wblank;
 
   FILE *output;
   int any_char;
@@ -125,6 +135,8 @@ private:
   static wstring wordzero(wstring const &chunk);
   bool checkIndex(xmlNode *element, int index, int limit);
   void postchunk_wrapper_null_flush(FILE *in, FILE *out);
+  bool gettingLemmaFromWord(string attr);
+  string combineWblanks(string wblank_current, string wblank_to_add);
 
 public:
   Postchunk();
